==> plugin-mq-client-2.0.8-20200715.100508-7-sources.jar: com/ohaotian/plugin/mq/proxy/impl/ProxyMessageRegister.java <==
package com.ohaotian.plugin.mq.proxy.impl;

import com.ohaotian.plugin.mq.proxy.ProxyMessageConsumer;
import com.ohaotian.plugin.mq.proxy.ProxyMessageType;
import com.ohaotian.plugin.mq.proxy.constants.LogUtils;
import com.ohaotian.plugin.mq.proxy.constants.MessageConfigUtils;
import com.ohaotian.plugin.mq.proxy.ext.ExtInfo;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;

import java.lang.reflect.Proxy;
import java.util.*;

public class ProxyMessageRegister implements ApplicationContextAware {

    public ProxyMessageRegister(){
        this.init();
    }

    private static final Logger logger = LoggerFactory.getLogger(ProxyMessageRegister.class);

    private void init() {
        // 关闭RocketMQ加载日志文件，防止业务系统的日志文件无法被加载
        System.setProperty("rocketmq.client.log.loadconfig","false");
    }

    private String strategy;
    private String enable;

    List<MQRegister> registerList = new LinkedList<MQRegister>();

    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        Boolean disable = MessageConfigUtils.isDisable(enable);
        if (disable){
            LogUtils.info(logger,"禁用插件，禁用消费者消息监听");
            return;
        }
        LogUtils.info(logger,"启用插件，启用消费者消息监听");

        Map<String, ? extends ProxyMessageConsumer> consumerMapping = applicationContext.getBeansOfType(ProxyMessageConsumer.class);
        Iterator<? extends ProxyMessageConsumer> consumers = consumerMapping.values().iterator();
        Map<String, ConsumerRegisterInfo> localStore = new HashMap<String, ConsumerRegisterInfo>();
        while (consumers.hasNext()) {
            ProxyMessageConsumer consumer = consumers.next();
            StringBuilder localStoreKey = new StringBuilder();
            localStoreKey.append(consumer.getSubject()).append("[");
            ProxyMessageType[] messageTypes = consumer.supportMessageTypes();
            for(ProxyMessageType messageType: messageTypes) {
                localStoreKey.append(messageType.name()).append("-");
            }
            localStoreKey.append("]");
            ConsumerRegisterInfo consumerRegisterInfo = localStore.get(localStoreKey.toString());
            if (consumerRegisterInfo == null) {
                consumerRegisterInfo = new ConsumerRegisterInfo(consumer.getId(), consumer.getSubject(), new HashSet<String>(), consumer.supportMessageTypes(), new HashSet<IProxyMessageConsumerWrapper>(), consumer.getProperties(), consumer.getQueueName());
                localStore.put(localStoreKey.toString(), consumerRegisterInfo);
            }
            Set<String> tagSet = consumerRegisterInfo.getTags();
            String[] tags = consumer.getTags();
            ProxyProducerFactoryBean.trans2TagSet(tagSet, tags);
            Set<IProxyMessageConsumerWrapper> localConsumers = consumerRegisterInfo.getConsumerWrappers();
            IProxyMessageConsumerWrapper proxyMessageConsumerWrapper = (IProxyMessageConsumerWrapper) Proxy.newProxyInstance(this.getClass().getClassLoader(), new Class[]{IProxyMessageConsumerWrapper.class}, new ConsumerInvokeHandler(consumer));
            localConsumers.add(proxyMessageConsumerWrapper);
            String localStrategy = consumer.getStrategy();
            if (localStrategy == null || "".equals(localStrategy)) {
                localStrategy = this.strategy;
            }
            ExtInfo extInfo = MQUtils.getExtInfoMapping().get(localStrategy);
            if (extInfo == null) {
                throw new IllegalStateException("mq.strategy[" + localStrategy + "] unsupported");
            }
            MQRegister mqRegister = extInfo.newRegister();
            if (mqRegister instanceof ApplicationContextAware) {
                ((ApplicationContextAware) mqRegister).setApplicationContext(applicationContext);
            }
            registerList.add(mqRegister);
            mqRegister.register(consumerRegisterInfo);
        }
        this.startup();
    }

    public void startup() {
        for(MQRegister register : registerList) {
            register.startup();
        }
    }

    public void shutdown() {
        for(MQRegister register : registerList) {
            register.shutdown();
        }
    }

    public void setStrategy(String strategy) {
        this.strategy = strategy;
    }

    public void setEnable(String enable) {
        this.enable = enable;
    }
}

==> plugin-mq-client-2.1.1-5-20230414.090756-2-sources.jar: com/ohaotian/plugin/mq/proxy/impl/ProxyMessageRegister.java <==
package com.ohaotian.plugin.mq.proxy.impl;

import com.ohaotian.plugin.mq.proxy.ProxyMessageConsumer;
import com.ohaotian.plugin.mq.proxy.ProxyMessageType;
import com.ohaotian.plugin.mq.proxy.config.ApolloConfigVO;
import com.ohaotian.plugin.mq.proxy.constants.LogUtils;
import com.ohaotian.plugin.mq.proxy.constants.MessageConfigUtils;
import com.ohaotian.plugin.mq.proxy.ext.ExtInfo;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;

import java.lang.reflect.Proxy;
import java.util.*;

public class ProxyMessageRegister implements ApplicationContextAware {

    public ProxyMessageRegister(){
        this.init();
    }

    private static final Logger logger = LoggerFactory.getLogger(ProxyMessageRegister.class);

    private void init() {
        // 关闭RocketMQ加载日志文件，防止业务系统的日志文件无法被加载
        System.setProperty("rocketmq.client.log.loadconfig","false");
    }

    private String strategy;
    private String enable;

    List<MQRegister> registerList = new LinkedList<MQRegister>();

    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        ApolloConfigVO bean = applicationContext.getBean(ApolloConfigVO.class);
        System.out.println(bean.toString());
        Boolean disable = MessageConfigUtils.isDisable(bean.getEnable());
        if (disable){
            LogUtils.info(logger,"禁用插件，禁用消费者消息监听");
            return;
        }
        LogUtils.info(logger,"启用插件，启用消费者消息监听");

        Map<String, ? extends ProxyMessageConsumer> consumerMapping = applicationContext.getBeansOfType(ProxyMessageConsumer.class);
        Iterator<? extends ProxyMessageConsumer> consumers = consumerMapping.values().iterator();
        Map<String, ConsumerRegisterInfo> localStore = new HashMap<String, ConsumerRegisterInfo>();
        while (consumers.hasNext()) {
            ProxyMessageConsumer consumer = consumers.next();
            StringBuilder localStoreKey = new StringBuilder();
            localStoreKey.append(consumer.getSubject()).append("[");
            ProxyMessageType[] messageTypes = consumer.supportMessageTypes();
            for(ProxyMessageType messageType: messageTypes) {
                localStoreKey.append(messageType.name()).append("-");
            }
            localStoreKey.append("]");
            ConsumerRegisterInfo consumerRegisterInfo = localStore.get(localStoreKey.toString());
            if (consumerRegisterInfo == null) {
                consumerRegisterInfo = new ConsumerRegisterInfo(consumer.getId(), consumer.getSubject(), new HashSet<String>(), consumer.supportMessageTypes(), new HashSet<IProxyMessageConsumerWrapper>(), consumer.getProperties(), consumer.getQueueName());
                localStore.put(localStoreKey.toString(), consumerRegisterInfo);
            }
            Set<String> tagSet = consumerRegisterInfo.getTags();
            String[] tags = consumer.getTags();
            ProxyProducerFactoryBean.trans2TagSet(tagSet, tags);
            Set<IProxyMessageConsumerWrapper> localConsumers = consumerRegisterInfo.getConsumerWrappers();
            IProxyMessageConsumerWrapper proxyMessageConsumerWrapper = (IProxyMessageConsumerWrapper) Proxy.newProxyInstance(this.getClass().getClassLoader(), new Class[]{IProxyMessageConsumerWrapper.class}, new ConsumerInvokeHandler(consumer));
            localConsumers.add(proxyMessageConsumerWrapper);
            String localStrategy =bean.getStrategy();
            if (localStrategy == null || "".equals(localStrategy)) {
                localStrategy = this.strategy;
            }
            ExtInfo extInfo = MQUtils.getExtInfoMapping().get(localStrategy);
            if (extInfo == null) {
                throw new IllegalStateException("mq.strategy[" + localStrategy + "] unsupported");
            }
            MQRegister mqRegister = extInfo.newRegister();
            if (mqRegister instanceof ApplicationContextAware) {
                ((ApplicationContextAware) mqRegister).setApplicationContext(applicationContext);
            }
            registerList.add(mqRegister);
            mqRegister.register(consumerRegisterInfo,bean);
        }
        this.startup();
    }

    public void startup() {
        for(MQRegister register : registerList) {
            register.startup();
        }
    }

    public void shutdown() {
        for(MQRegister register : registerList) {
            register.shutdown();
        }
    }

    public void setStrategy(String strategy) {
        this.strategy = strategy;
    }

    public void setEnable(String enable) {
        this.enable = enable;
    }
}
